@@ -33,7 +33,8 @@ class WidgetBase(ABC):
         pass
 
     def contains(self, x, y):
-        return self._x < x < self._x + self._width and self._y < y < self._y + self._height
+        return (self._x < x - self.win.get_abs_offset()[0] < self._x + self._width) and\
+               (self._y < y - self.win.get_abs_offset()[1] < self._y + self._height)
 
     def hide(self):
         self._hidden = True
